PostgresStore

Struct PostgresStore 

pub struct PostgresStore { /* private fields */ }
PostgreSQL implementation of Store trait

Implementations

Source

impl PostgresStore

pub fn new(pool: PgPool) -> Self

pub fn pool(&self) -> &PgPool

pub async fn is_processed(&self, event_id: Uuid) -> Result<bool>

Check if an event has already been processed (for idempotency).

This is used by the Kafka backend to prevent duplicate processing when Kafka redelivers messages.